package com.jz.dm.controller;

import com.jz.common.utils.Result;
import com.jz.dm.models.req.api.ApiInterfaceDetailReq;
import com.jz.dm.models.req.api.ApiInterfaceInfoListReq;
import com.jz.dm.service.ApiInterfaceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Mono;

import javax.validation.Valid;

/**
 * @author ZC
 * @PACKAGE_NAME: com.jz.dm.controller
 * @PROJECT_NAME: jz-dm-parent
 * @NAME: ApiInterfaceController
 * @DATE: 2021-1-14/15:29
 * @DAY_NAME_SHORT: 周四
 * @Description:
 **/
@RestController
@RequestMapping("api/interface")
@Api(tags = "API接口Controller")
public class ApiInterfaceController {

    @Autowired
    private ApiInterfaceService apiInterfaceService;

    /**
     * @Description:API列表查询
     * @return: API列表
     * @Author: Mr.zhang
     * @Date: 2020-12-24
     */
    @ApiOperation("API---(已调用列表)列表查询")
    @PostMapping(value = "/listApiInterface")
    public Mono<Result> getApiInterfaceCallList(@RequestBody @Valid ApiInterfaceInfoListReq req) {
        return Mono.fromSupplier(() -> Result.of_success(apiInterfaceService.listCallApiInterface(req)));
    }
    /**
     * @Description:API列表查询
     * @return: API列表
     * @Author: Mr.zhang
     * @Date: 2020-12-24
     */
    @ApiOperation("API---(未调用列表)列表查询")
    @PostMapping(value = "/listUnCallApiInterface")
    public Mono<Result> getApiInterfaceList(@RequestBody @Valid ApiInterfaceInfoListReq req) {
        return Mono.fromSupplier(() -> Result.of_success(apiInterfaceService.listUnCallApiInterface(req)));
    }
    /**
     * @Description:API详情查询
     * @return: API详情查询
     * @Author: Mr.zhang
     * @Date: 2020-12-24
     */
    @ApiOperation("API详情查询")
    @PostMapping(value = "/getApiInterfaceDetail")
    public Mono<Result> getApiInterfaceDetail(@RequestBody @Valid ApiInterfaceDetailReq req) {
        return Mono.fromSupplier(() -> apiInterfaceService.getApiInterfaceDetail(req));
    }
    /**
     * @Description:API删除
     * @return: API删除
     * @Author: Mr.zhang
     * @Date: 2020-12-24
     */
    @ApiOperation("数据银行API删除")
    @PostMapping(value = "/delDataBankApiInterface")
    public Mono<Result> delDataBankApiInterface(@RequestParam (name="apiKey")String apiKey) {
        return Mono.fromSupplier(() -> apiInterfaceService.delApiInterface(apiKey));
    }
    /**
     * @Description:DMP-API删除
     * @return: DMP-API删除
     * @Author: Mr.zhang
     * @Date: 2020-12-24
     */
    @ApiOperation("DMP-API删除/确认提示接口")
    @GetMapping(value = "/delDMPApiInterface")
    public Mono<Result> delDMPApiInterface(@RequestParam (name="type")String type,
                                           @RequestParam (name="apiKey")String apiKey) {
        return Mono.fromSupplier(() -> apiInterfaceService.dmpDeleteAuth(type,apiKey));
    }


}
