package com.jz.dm.controller;

import com.jz.common.utils.Result;
import com.jz.dm.models.req.auth.*;
import com.jz.dm.service.AuthService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Mono;

import javax.validation.Valid;

/**
 * @author ZC
 * @PACKAGE_NAME: com.jz.dm.controller
 * @PROJECT_NAME: jz-dm-parent
 * @NAME: AuthController
 * @DATE: 2020-12-23/16:38
 * @DAY_NAME_SHORT: 周三
 * @Description: 授权controller
 **/
@RestController
@RequestMapping("api/auth")
@Api(tags = "授权认证Controller")
public class AuthController {

    @Autowired
    private AuthService authService;

    /**
     * @Description:商城用户API认证
     * @return: 商城用户API认证
     * @Author: Mr.zhang
     * @Date: 2020-12-26
     */
    @ApiOperation("商城用户API认证")
    @PostMapping(value = "/mall-user-auth-api")
    public Mono<Result> authMallUserApi(@RequestBody @Valid AuthUserApiReq req) {
        return Mono.fromSupplier(() -> authService.addMallUserApiAuth(req));
    }
    /**
     * @Description:DMP用户API认证
     * @return: DMP用户API认证
     * @Author: Mr.zhang
     * @Date: 2020-12-26
     */
    @ApiOperation("DMP用户API认证")
    @PostMapping(value = "dmp-auth-api")
    public Mono<Result> authDmpUserApi(@RequestBody @Valid AuthUserApiReq req) {
        return Mono.fromSupplier(() -> authService.addDmpUserApiAuth(req));
    }
    /**
     * @Description: 认证详情查询
     * @return: 认证详情查询
     * @Author: Mr.zhang
     * @Date: 2020-12-26
     */
    @ApiOperation("认证详情查询")
    @PostMapping(value = "/auth-detail-info")
    public Mono<Result> selectAuthDetailInfo(@RequestBody @Valid AuthDetailInfoReq req) {
        return Mono.fromSupplier(() -> authService.getAuthDetailInfo(req));
    }
    /**
     * @Description: 认证列表查询
     * @return: 认证列表查询
     * @Author: Mr.zhang
     * @Date: 2020-12-26
     */
    @ApiOperation("认证列表查询")
    @PostMapping(value = "/auth-list")
    public Mono<Result> selectAuthListInfo(@RequestBody @Valid AuthListInfoReq req) {
        return Mono.fromSupplier(() -> authService.getAuthListInfo(req));
    }
    /**
     * @Description: 授权模糊查询列表信息
     * @return: 认证列表查询
     * @Author: Mr.zhang
     * @Date: 2020-12-26
     */
    @ApiOperation("授权模糊查询列表信息")
    @GetMapping(value = "/getAuthNameList")
    public Mono<Result> getAuthNameList(@RequestParam("key") String key) {
        return Mono.fromSupplier(() -> authService.getAuthNameList(key));
    }
    /**
     * @Description: 认证信息修改
     * @return: 认证信息修改
     * @Author: Mr.zhang
     * @Date: 2020-12-26
     */
    @ApiOperation("取消授权")
    @PostMapping(value = "/update-auth-info")
    public Mono<Result> updateAuthListInfo(@RequestBody @Valid AuthInfoUpdateReq req) {
        return Mono.fromSupplier(() -> authService.updateAuthInfo(req));
    }
    /**
     * @Description: 盐值重置接口
     * @return: 盐值重置接口
     * @Author: Mr.zhang
     * @Date: 2020-12-26
     */
    @ApiOperation("盐值重置接口")
    @PostMapping(value = "/reset-salt")
    public Mono<Result> resetSalt(@RequestBody @Validated SaltResetReq req) {
        return Mono.fromSupplier(() -> authService.updateSaltInfo(req));
    }
}
